@@ -2137,7 +2137,7 @@ async def get_subproject_id_by_name(
         
         # Get all sub-projects to find the ID by name
         # Handle both project keys (like "FS", "PROJ") and project IDs (like 123)
-        sub_projects_url = f"https://{FRESHRELEASE_DOMAIN}/api/projects/{project_id}/sub_projects"
+        sub_projects_url = f"https://{FRESHRELEASE_DOMAIN}/api/{project_id}/sub_projects"
         
         logging.info(f"Fetching sub-projects from: {sub_projects_url}")
         sub_projects_response = await client.get(sub_projects_url, headers=headers)
@@ -2151,33 +2151,21 @@ async def get_subproject_id_by_name(
         
         sub_projects_data = sub_projects_response.json()
         
-        # Debug: Log the actual response structure
-        logging.info(f"Sub-projects API response structure: {type(sub_projects_data)}")
-        logging.info(f"Sub-projects API response keys: {list(sub_projects_data.keys()) if isinstance(sub_projects_data, dict) else 'Not a dict'}")
-        
-        # Handle different possible response structures
-        if isinstance(sub_projects_data, list):
-            # Response is directly a list of sub-projects
-            sub_projects = sub_projects_data
-        elif isinstance(sub_projects_data, dict):
-            # Response is an object, try different possible keys
-            sub_projects = (sub_projects_data.get("sub_projects") or 
-                          sub_projects_data.get("subprojects") or 
-                          sub_projects_data.get("sub_project") or
-                          sub_projects_data.get("data") or
-                          sub_projects_data.get("results") or [])
+        # Handle the standard sub-projects API response structure
+        if isinstance(sub_projects_data, dict) and "sub_projects" in sub_projects_data:
+            sub_projects = sub_projects_data["sub_projects"]
         else:
+            logging.error(f"Unexpected sub-projects API response structure: {sub_projects_data}")
             return {
-                "error": f"Unexpected response structure for sub_projects",
-                "response_type": str(type(sub_projects_data)),
-                "response_preview": str(sub_projects_data)[:500]  # First 500 chars for debugging
+                "error": f"Unexpected response structure for sub_projects API",
+                "response_keys": list(sub_projects_data.keys()) if isinstance(sub_projects_data, dict) else None,
+                "response_type": str(type(sub_projects_data))
             }
         
-        # Validate we have a list to work with
+        # Validate we have a list of sub-projects
         if not isinstance(sub_projects, list):
             return {
                 "error": f"Expected sub_projects to be a list, got {type(sub_projects)}",
-                "response_data": sub_projects_data,
                 "sub_projects_value": sub_projects
             }
         
